==> estateplat-common-1.2.4-20241122.063233-1271-sources.jar: cn/gtmap/estateplat/model/server/core/BdcSpxx.java <==
package cn.gtmap.estateplat.model.server.core;

import cn.gtmap.estateplat.core.annotation.Zd;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * 不动产登记项目审批信息
 *
 * @author <a href="mailto:shenjian@gtmap.cn">jane</a>
 * @version 1.0, 2015/11/1
 */
@Table(name = "bdc_spxx")
public class BdcSpxx implements Serializable, BdcProid, InsertVo {
    @Id
    private String spxxid;//审批信息Id

    private String proid;    //不动产登记项目Id

    private String csyj;//初审意见

    private String csr;//初审人

    private String csrsignid;//初审人签名ID

    private Date csrq;//初审日期

    private String fsyj;//复审意见

    private String fsr;//复审人

    private String fsrsignid;//复审人签名ID

    private Date fsrq;//复审日期

    private String hdyj;//核定意见

    private String hdr;//核定人

    private String hdrsignid;//核定人签名ID

    private Date hdrq;//核定日期

    private String zl;//坐落

    private String bdcdyh;//不动产单元号

    private String bdclx;//不动产类型

    private Double mj;//面积

    @Zd(table = "bdc_zd_fwyt")
    private String yt;//用途

    private String yhlx;//用海类型

    private String yhlxb;//用海类型

    private String gzwlx;//构筑物类型

    private String lz;//林种

    private String mjdw;//面积单位

    private Double zdzhmj;//宗地宗海面积

    @Zd(table = "djsj_zd_dldm")
    private String zdzhyt;//宗地宗海用途

    @Zd(table = "bdc_zd_qlxz")
    private String zdzhqlxz;//宗地宗海权利性质

    private String fcghyt;//房产规划用途

    private String yhspdw;//用海审批单位

    private String pzwh;//批准文号


    private Double scmj;//面积


    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 宗地宗海用途2
     */
    private String zdzhyt2;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 宗地宗海用途3
     */
    private String zdzhyt3;

    /**
     * @description 定着物用途2
     */
    private String yt2;

    /**
     * @description 定着物用途3
     */
    private String yt3;


    private String qlqtzk;//权利其他状况


    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 宗地宗海面积2
     */
    private Double zdzhmj2;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 宗地宗海面积3
     */
    private Double zdzhmj3;


    //宗地批准面积
    private Double zdpzmj;
    //房屋批准建筑面积
    private Double fwpzjzmj;

    private Date xyshsj;//信用审核时间

    private String xyshr;//信用审核人
    private String xyshzt;//信用审核状态
    private String xyshyj;//信用审核意见

    private Double fzmj;//发证面积

    private String dh;//栋号
    private Integer sxh;//室序号
    private Double jzjzzdmj;//建筑基座占地面积
    private Double qqtdmj;//确权土地面积
    private Double qqjzmj;//确权建筑面积
    private String qyqzdz;//企业签章地址

    // 同步过户
    private String tbgh;

    public Double getZdzhmj() {
        return zdzhmj;
    }

    public void setZdzhmj(Double zdzhmj) {
        this.zdzhmj = zdzhmj;
    }

    public String getZdzhyt() {
        return zdzhyt;
    }

    public void setZdzhyt(String zdzhyt) {
        this.zdzhyt = zdzhyt;
    }

    public String getZdzhqlxz() {
        return zdzhqlxz;
    }

    public void setZdzhqlxz(String zdzhqlxz) {
        this.zdzhqlxz = zdzhqlxz;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getBdclx() {
        return bdclx;
    }

    public void setBdclx(String bdclx) {
        this.bdclx = bdclx;
    }

    public Double getMj() {
        return mj;
    }

    public void setMj(Double mj) {
        this.mj = mj;
    }

    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }

    public String getYhlx() {
        return yhlx;
    }

    public void setYhlx(String yhlx) {
        this.yhlx = yhlx;
    }

    public String getGzwlx() {
        return gzwlx;
    }

    public void setGzwlx(String gzwlx) {
        this.gzwlx = gzwlx;
    }

    public String getLz() {
        return lz;
    }

    public void setLz(String lz) {
        this.lz = lz;
    }

    public String getMjdw() {
        return mjdw;
    }

    public void setMjdw(String mjdw) {
        this.mjdw = mjdw;
    }

    public String getSpxxid() {
        return spxxid;
    }

    public void setSpxxid(String spxxid) {
        this.spxxid = spxxid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getCsyj() {
        return csyj;
    }

    public void setCsyj(String csyj) {
        this.csyj = csyj;
    }

    public String getCsr() {
        return csr;
    }

    public void setCsr(String csr) {
        this.csr = csr;
    }

    public String getCsrsignid() {
        return csrsignid;
    }

    public void setCsrsignid(String csrsignid) {
        this.csrsignid = csrsignid;
    }

    public Date getCsrq() {
        return csrq;
    }

    public void setCsrq(Date csrq) {
        this.csrq = csrq;
    }

    public String getFsyj() {
        return fsyj;
    }

    public void setFsyj(String fsyj) {
        this.fsyj = fsyj;
    }

    public String getFsr() {
        return fsr;
    }

    public void setFsr(String fsr) {
        this.fsr = fsr;
    }

    public String getFsrsignid() {
        return fsrsignid;
    }

    public void setFsrsignid(String fsrsignid) {
        this.fsrsignid = fsrsignid;
    }

    public Date getFsrq() {
        return fsrq;
    }

    public void setFsrq(Date fsrq) {
        this.fsrq = fsrq;
    }

    public String getHdyj() {
        return hdyj;
    }

    public void setHdyj(String hdyj) {
        this.hdyj = hdyj;
    }

    public String getHdr() {
        return hdr;
    }

    public void setHdr(String hdr) {
        this.hdr = hdr;
    }

    public String getHdrsignid() {
        return hdrsignid;
    }

    public void setHdrsignid(String hdrsignid) {
        this.hdrsignid = hdrsignid;
    }

    public Date getHdrq() {
        return hdrq;
    }

    public void setHdrq(Date hdrq) {
        this.hdrq = hdrq;
    }

    public String getFcghyt() {
        return fcghyt;
    }

    public void setFcghyt(String fcghyt) {
        this.fcghyt = fcghyt;
    }

    public String getZdzhyt2() {
        return zdzhyt2;
    }

    public void setZdzhyt2(String zdzhyt2) {
        this.zdzhyt2 = zdzhyt2;
    }

    public String getZdzhyt3() {
        return zdzhyt3;
    }

    public void setZdzhyt3(String zdzhyt3) {
        this.zdzhyt3 = zdzhyt3;
    }

    public String getYt2() {
        return yt2;
    }

    public void setYt2(String yt2) {
        this.yt2 = yt2;
    }

    public String getYt3() {
        return yt3;
    }

    public void setYt3(String yt3) {
        this.yt3 = yt3;
    }

    public String getQlqtzk() {
        return qlqtzk;
    }

    public void setQlqtzk(String qlqtzk) {
        this.qlqtzk = qlqtzk;
    }

    public String getYhspdw() {
        return yhspdw;
    }

    public void setYhspdw(String yhspdw) {
        this.yhspdw = yhspdw;
    }

    public String getPzwh() {
        return pzwh;
    }

    public void setPzwh(String pzwh) {
        this.pzwh = pzwh;
    }

    public String getYhlxb() {
        return yhlxb;
    }

    public void setYhlxb(String yhlxb) {
        this.yhlxb = yhlxb;
    }

    public Double getZdzhmj2() {
        return zdzhmj2;
    }

    public void setZdzhmj2(Double zdzhmj2) {
        this.zdzhmj2 = zdzhmj2;
    }

    public Double getZdzhmj3() {
        return zdzhmj3;
    }

    public void setZdzhmj3(Double zdzhmj3) {
        this.zdzhmj3 = zdzhmj3;
    }

    public Double getScmj() {
        return scmj;
    }

    public void setScmj(Double scmj) {
        this.scmj = scmj;
    }

    public Double getZdpzmj() {
        return zdpzmj;
    }

    public void setZdpzmj(Double zdpzmj) {
        this.zdpzmj = zdpzmj;
    }

    public Double getFwpzjzmj() {
        return fwpzjzmj;
    }

    public void setFwpzjzmj(Double fwpzjzmj) {
        this.fwpzjzmj = fwpzjzmj;
    }

    public Date getXyshsj() {
        return xyshsj;
    }

    public void setXyshsj(Date xyshsj) {
        this.xyshsj = xyshsj;
    }

    public String getXyshr() {
        return xyshr;
    }

    public void setXyshr(String xyshr) {
        this.xyshr = xyshr;
    }

    public String getXyshzt() {
        return xyshzt;
    }

    public void setXyshzt(String xyshzt) {
        this.xyshzt = xyshzt;
    }

    public String getXyshyj() {
        return xyshyj;
    }

    public void setXyshyj(String xyshyj) {
        this.xyshyj = xyshyj;
    }

    public Double getFzmj() {
        return fzmj;
    }

    public void setFzmj(Double fzmj) {
        this.fzmj = fzmj;
    }

    public String getDh() {
        return dh;
    }

    public void setDh(String dh) {
        this.dh = dh;
    }

    public Integer getSxh() {
        return sxh;
    }

    public void setSxh(Integer sxh) {
        this.sxh = sxh;
    }

    public Double getJzjzzdmj() {
        return jzjzzdmj;
    }

    public void setJzjzzdmj(Double jzjzzdmj) {
        this.jzjzzdmj = jzjzzdmj;
    }

    public Double getQqtdmj() {
        return qqtdmj;
    }

    public void setQqtdmj(Double qqtdmj) {
        this.qqtdmj = qqtdmj;
    }

    public Double getQqjzmj() {
        return qqjzmj;
    }

    public void setQqjzmj(Double qqjzmj) {
        this.qqjzmj = qqjzmj;
    }

    public String getQyqzdz() {
        return qyqzdz;
    }

    public void setQyqzdz(String qyqzdz) {
        this.qyqzdz = qyqzdz;
    }

    public String getTbgh() {
        return tbgh;
    }

    public void setTbgh(String tbgh) {
        this.tbgh = tbgh;
    }
}

==> estateplat-common-1.2.4-20251208.030812-1316-sources.jar: cn/gtmap/estateplat/model/server/core/BdcSpxx.java <==
package cn.gtmap.estateplat.model.server.core;

import cn.gtmap.estateplat.core.annotation.Zd;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * 不动产登记项目审批信息
 *
 * @author <a href="mailto:shenjian@gtmap.cn">jane</a>
 * @version 1.0, 2015/11/1
 */
@Table(name = "bdc_spxx")
public class BdcSpxx implements Serializable, BdcProid, InsertVo {
    @Id
    private String spxxid;//审批信息Id

    private String proid;    //不动产登记项目Id

    private String csyj;//初审意见

    private String csr;//初审人

    private String csrsignid;//初审人签名ID

    private Date csrq;//初审日期

    private String fsyj;//复审意见

    private String fsr;//复审人

    private String fsrsignid;//复审人签名ID

    private Date fsrq;//复审日期

    private String hdyj;//核定意见

    private String hdr;//核定人

    private String hdrsignid;//核定人签名ID

    private Date hdrq;//核定日期

    private String zl;//坐落

    private String bdcdyh;//不动产单元号

    private String bdclx;//不动产类型

    private Double mj;//面积

    @Zd(table = "bdc_zd_fwyt")
    private String yt;//用途

    private String yhlx;//用海类型

    private String yhlxb;//用海类型

    private String gzwlx;//构筑物类型

    private String lz;//林种

    private String mjdw;//面积单位

    private Double zdzhmj;//宗地宗海面积

    @Zd(table = "djsj_zd_dldm")
    private String zdzhyt;//宗地宗海用途

    @Zd(table = "bdc_zd_qlxz")
    private String zdzhqlxz;//宗地宗海权利性质

    private String fcghyt;//房产规划用途

    private String yhspdw;//用海审批单位

    private String pzwh;//批准文号


    private Double scmj;//面积


    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 宗地宗海用途2
     */
    private String zdzhyt2;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 宗地宗海用途3
     */
    private String zdzhyt3;

    /**
     * @description 定着物用途2
     */
    private String yt2;

    /**
     * @description 定着物用途3
     */
    private String yt3;


    private String qlqtzk;//权利其他状况


    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 宗地宗海面积2
     */
    private Double zdzhmj2;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 宗地宗海面积3
     */
    private Double zdzhmj3;


    //宗地批准面积
    private Double zdpzmj;
    //房屋批准建筑面积
    private Double fwpzjzmj;

    private Date xyshsj;//信用审核时间

    private String xyshr;//信用审核人
    private String xyshzt;//信用审核状态
    private String xyshyj;//信用审核意见

    private Double fzmj;//发证面积

    private String dh;//栋号
    private Integer sxh;//室序号
    private Double jzjzzdmj;//建筑基座占地面积
    private Double qqtdmj;//确权土地面积
    private Double qqjzmj;//确权建筑面积
    private String qyqzdz;//企业签章地址

    // 同步过户
    private String tbgh;

    private Double zfscmj;//主房实测面积

    public Double getZdzhmj() {
        return zdzhmj;
    }

    public void setZdzhmj(Double zdzhmj) {
        this.zdzhmj = zdzhmj;
    }

    public String getZdzhyt() {
        return zdzhyt;
    }

    public void setZdzhyt(String zdzhyt) {
        this.zdzhyt = zdzhyt;
    }

    public String getZdzhqlxz() {
        return zdzhqlxz;
    }

    public void setZdzhqlxz(String zdzhqlxz) {
        this.zdzhqlxz = zdzhqlxz;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getBdclx() {
        return bdclx;
    }

    public void setBdclx(String bdclx) {
        this.bdclx = bdclx;
    }

    public Double getMj() {
        return mj;
    }

    public void setMj(Double mj) {
        this.mj = mj;
    }

    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }

    public String getYhlx() {
        return yhlx;
    }

    public void setYhlx(String yhlx) {
        this.yhlx = yhlx;
    }

    public String getGzwlx() {
        return gzwlx;
    }

    public void setGzwlx(String gzwlx) {
        this.gzwlx = gzwlx;
    }

    public String getLz() {
        return lz;
    }

    public void setLz(String lz) {
        this.lz = lz;
    }

    public String getMjdw() {
        return mjdw;
    }

    public void setMjdw(String mjdw) {
        this.mjdw = mjdw;
    }

    public String getSpxxid() {
        return spxxid;
    }

    public void setSpxxid(String spxxid) {
        this.spxxid = spxxid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getCsyj() {
        return csyj;
    }

    public void setCsyj(String csyj) {
        this.csyj = csyj;
    }

    public String getCsr() {
        return csr;
    }

    public void setCsr(String csr) {
        this.csr = csr;
    }

    public String getCsrsignid() {
        return csrsignid;
    }

    public void setCsrsignid(String csrsignid) {
        this.csrsignid = csrsignid;
    }

    public Date getCsrq() {
        return csrq;
    }

    public void setCsrq(Date csrq) {
        this.csrq = csrq;
    }

    public String getFsyj() {
        return fsyj;
    }

    public void setFsyj(String fsyj) {
        this.fsyj = fsyj;
    }

    public String getFsr() {
        return fsr;
    }

    public void setFsr(String fsr) {
        this.fsr = fsr;
    }

    public String getFsrsignid() {
        return fsrsignid;
    }

    public void setFsrsignid(String fsrsignid) {
        this.fsrsignid = fsrsignid;
    }

    public Date getFsrq() {
        return fsrq;
    }

    public void setFsrq(Date fsrq) {
        this.fsrq = fsrq;
    }

    public String getHdyj() {
        return hdyj;
    }

    public void setHdyj(String hdyj) {
        this.hdyj = hdyj;
    }

    public String getHdr() {
        return hdr;
    }

    public void setHdr(String hdr) {
        this.hdr = hdr;
    }

    public String getHdrsignid() {
        return hdrsignid;
    }

    public void setHdrsignid(String hdrsignid) {
        this.hdrsignid = hdrsignid;
    }

    public Date getHdrq() {
        return hdrq;
    }

    public void setHdrq(Date hdrq) {
        this.hdrq = hdrq;
    }

    public String getFcghyt() {
        return fcghyt;
    }

    public void setFcghyt(String fcghyt) {
        this.fcghyt = fcghyt;
    }

    public String getZdzhyt2() {
        return zdzhyt2;
    }

    public void setZdzhyt2(String zdzhyt2) {
        this.zdzhyt2 = zdzhyt2;
    }

    public String getZdzhyt3() {
        return zdzhyt3;
    }

    public void setZdzhyt3(String zdzhyt3) {
        this.zdzhyt3 = zdzhyt3;
    }

    public String getYt2() {
        return yt2;
    }

    public void setYt2(String yt2) {
        this.yt2 = yt2;
    }

    public String getYt3() {
        return yt3;
    }

    public void setYt3(String yt3) {
        this.yt3 = yt3;
    }

    public String getQlqtzk() {
        return qlqtzk;
    }

    public void setQlqtzk(String qlqtzk) {
        this.qlqtzk = qlqtzk;
    }

    public String getYhspdw() {
        return yhspdw;
    }

    public void setYhspdw(String yhspdw) {
        this.yhspdw = yhspdw;
    }

    public String getPzwh() {
        return pzwh;
    }

    public void setPzwh(String pzwh) {
        this.pzwh = pzwh;
    }

    public String getYhlxb() {
        return yhlxb;
    }

    public void setYhlxb(String yhlxb) {
        this.yhlxb = yhlxb;
    }

    public Double getZdzhmj2() {
        return zdzhmj2;
    }

    public void setZdzhmj2(Double zdzhmj2) {
        this.zdzhmj2 = zdzhmj2;
    }

    public Double getZdzhmj3() {
        return zdzhmj3;
    }

    public void setZdzhmj3(Double zdzhmj3) {
        this.zdzhmj3 = zdzhmj3;
    }

    public Double getScmj() {
        return scmj;
    }

    public void setScmj(Double scmj) {
        this.scmj = scmj;
    }

    public Double getZdpzmj() {
        return zdpzmj;
    }

    public void setZdpzmj(Double zdpzmj) {
        this.zdpzmj = zdpzmj;
    }

    public Double getFwpzjzmj() {
        return fwpzjzmj;
    }

    public void setFwpzjzmj(Double fwpzjzmj) {
        this.fwpzjzmj = fwpzjzmj;
    }

    public Date getXyshsj() {
        return xyshsj;
    }

    public void setXyshsj(Date xyshsj) {
        this.xyshsj = xyshsj;
    }

    public String getXyshr() {
        return xyshr;
    }

    public void setXyshr(String xyshr) {
        this.xyshr = xyshr;
    }

    public String getXyshzt() {
        return xyshzt;
    }

    public void setXyshzt(String xyshzt) {
        this.xyshzt = xyshzt;
    }

    public String getXyshyj() {
        return xyshyj;
    }

    public void setXyshyj(String xyshyj) {
        this.xyshyj = xyshyj;
    }

    public Double getFzmj() {
        return fzmj;
    }

    public void setFzmj(Double fzmj) {
        this.fzmj = fzmj;
    }

    public String getDh() {
        return dh;
    }

    public void setDh(String dh) {
        this.dh = dh;
    }

    public Integer getSxh() {
        return sxh;
    }

    public void setSxh(Integer sxh) {
        this.sxh = sxh;
    }

    public Double getJzjzzdmj() {
        return jzjzzdmj;
    }

    public void setJzjzzdmj(Double jzjzzdmj) {
        this.jzjzzdmj = jzjzzdmj;
    }

    public Double getQqtdmj() {
        return qqtdmj;
    }

    public void setQqtdmj(Double qqtdmj) {
        this.qqtdmj = qqtdmj;
    }

    public Double getQqjzmj() {
        return qqjzmj;
    }

    public void setQqjzmj(Double qqjzmj) {
        this.qqjzmj = qqjzmj;
    }

    public String getQyqzdz() {
        return qyqzdz;
    }

    public void setQyqzdz(String qyqzdz) {
        this.qyqzdz = qyqzdz;
    }

    public String getTbgh() {
        return tbgh;
    }

    public void setTbgh(String tbgh) {
        this.tbgh = tbgh;
    }

    public Double getZfscmj() {
        return zfscmj;
    }

    public void setZfscmj(Double zfscmj) {
        this.zfscmj = zfscmj;
    }
}
